@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::CmdLineParsingModules;
 
-our $VERSION = 0.07; # VERSION
+our $VERSION = "0.080"; # VERSION
 
 our $results = [
   [
@@ -9,111 +9,147 @@ our $results = [
     [
       {
         dataset     => "4args",
-        errors      => 5.3e-08,
+        errors      => 1.1e-08,
         participant => "Parse::CommandLine::parse_command_line",
-        rate        => 34000,
-        samples     => 20,
-        time        => 29,
-        vs_slowest  => 1,
-      },
-      {
-        dataset     => "4args",
-        errors      => 5.3e-08,
-        participant => "Text::ParseWords::shellwords",
-        rate        => 34000,
-        samples     => 20,
-        time        => 29,
+        rate        => 31800,
+        samples     => 27,
+        time        => 31.4,
         vs_slowest  => 1,
       },
       {
         dataset     => "4args",
         errors      => 1.3e-08,
         participant => "Complete::Bash::parse_cmdline",
-        rate        => 38400,
+        rate        => 33500,
+        samples     => 21,
+        time        => 29.8,
+        vs_slowest  => 1.05,
+      },
+      {
+        dataset     => "4args",
+        errors      => 9.1e-11,
+        participant => "Text::ParseWords::shellwords",
+        rate        => 37046,
         samples     => 20,
-        time        => 26.1,
-        vs_slowest  => 1.13,
+        time        => 26.993,
+        vs_slowest  => 1.1637,
+      },
+      {
+        dataset     => "4args",
+        errors      => 2.6e-08,
+        participant => "Parse::CommandLine::Regexp::parse_command_line",
+        rate        => 54000,
+        samples     => 21,
+        time        => 18,
+        vs_slowest  => 1.7,
+      },
+      {
+        dataset     => "2args-simple",
+        errors      => 1.3e-08,
+        participant => "Complete::Bash::parse_cmdline",
+        rate        => 84000,
+        samples     => 21,
+        time        => 12,
+        vs_slowest  => 2.6,
+      },
+      {
+        dataset     => "2args-simple",
+        errors      => 1.3e-08,
+        participant => "Text::ParseWords::shellwords",
+        rate        => 95000,
+        samples     => 20,
+        time        => 11,
+        vs_slowest  => 3,
       },
       {
         dataset     => "2args-simple",
         errors      => 1e-08,
-        participant => "Text::ParseWords::shellwords",
-        rate        => 83700,
-        samples     => 20,
-        time        => 11.9,
-        vs_slowest  => 2.46,
-      },
-      {
-        dataset     => "2args-simple",
-        errors      => 2.9e-09,
-        participant => "Complete::Bash::parse_cmdline",
-        rate        => 93400,
-        samples     => 26,
-        time        => 10.7,
-        vs_slowest  => 2.74,
-      },
-      {
-        dataset     => "2args-simple",
-        errors      => 2.2e-08,
         participant => "Parse::CommandLine::parse_command_line",
         rate        => 130000,
-        samples     => 37,
-        time        => 7.8,
-        vs_slowest  => 3.8,
+        samples     => 20,
+        time        => 7.7,
+        vs_slowest  => 4.1,
+      },
+      {
+        dataset     => "2args-simple",
+        errors      => 3.3e-09,
+        participant => "Parse::CommandLine::Regexp::parse_command_line",
+        rate        => 136000,
+        samples     => 20,
+        time        => 7.33,
+        vs_slowest  => 4.29,
       },
       {
         dataset     => "cmd-only",
-        errors      => 1.7e-09,
+        errors      => 1e-07,
         participant => "Complete::Bash::parse_cmdline",
-        rate        => 214000,
-        samples     => 20,
-        time        => 4.67,
-        vs_slowest  => 6.28,
+        rate        => 200000,
+        samples     => 29,
+        time        => 5,
+        vs_slowest  => 6,
       },
       {
         dataset     => "cmd-only",
         errors      => 1.7e-09,
         participant => "Text::ParseWords::shellwords",
-        rate        => 216000,
+        rate        => 236000,
         samples     => 20,
-        time        => 4.62,
-        vs_slowest  => 6.35,
+        time        => 4.24,
+        vs_slowest  => 7.41,
       },
       {
         dataset     => "cmd-only",
-        errors      => 7.9e-10,
+        errors      => 1.1e-11,
         participant => "Parse::CommandLine::parse_command_line",
-        rate        => 358000,
+        rate        => 334760,
+        samples     => 27,
+        time        => 2.9872,
+        vs_slowest  => 10.515,
+      },
+      {
+        dataset     => "cmd-only",
+        errors      => 3.1e-09,
+        participant => "Parse::CommandLine::Regexp::parse_command_line",
+        rate        => 340000,
+        samples     => 23,
+        time        => 2.9,
+        vs_slowest  => 11,
+      },
+      {
+        dataset     => "empty",
+        errors      => 4.1e-10,
+        participant => "Complete::Bash::parse_cmdline",
+        rate        => 1030000,
+        samples     => 31,
+        time        => 0.967,
+        vs_slowest  => 32.5,
+      },
+      {
+        dataset     => "empty",
+        errors      => 1.6e-09,
+        participant => "Text::ParseWords::shellwords",
+        rate        => 1300000,
+        samples     => 23,
+        time        => 0.78,
+        vs_slowest  => 40,
+      },
+      {
+        dataset     => "empty",
+        errors      => 9.3e-10,
+        participant => "Parse::CommandLine::parse_command_line",
+        rate        => 2600000,
+        samples     => 25,
+        time        => 0.39,
+        vs_slowest  => 81,
+      },
+      {
+        dataset     => "empty",
+        errors      => 1.2e-11,
+        participant => "Parse::CommandLine::Regexp::parse_command_line",
+        rate        => 5848000,
         samples     => 22,
-        time        => 2.79,
-        vs_slowest  => 10.5,
-      },
-      {
-        dataset     => "empty",
-        errors      => 1e-11,
-        participant => "Text::ParseWords::shellwords",
-        rate        => 1181000,
-        samples     => 20,
-        time        => 0.8466,
-        vs_slowest  => 34.66,
-      },
-      {
-        dataset     => "empty",
-        errors      => 2.9e-11,
-        participant => "Complete::Bash::parse_cmdline",
-        rate        => 1276000,
-        samples     => 20,
-        time        => 0.7839,
-        vs_slowest  => 37.43,
-      },
-      {
-        dataset     => "empty",
-        errors      => 6.1e-10,
-        participant => "Parse::CommandLine::parse_command_line",
-        rate        => 3000000,
-        samples     => 21,
-        time        => 0.34,
-        vs_slowest  => 87,
+        time        => 0.171,
+        vs_slowest  => 183.7,
       },
     ],
     {
@@ -123,6 +159,7 @@ our $results = [
                                             scenario_module => "CmdLineParsingModules",
                                           },
       "func.bencher_version"           => undef,
+      "func.code_startup"              => undef,
       "func.cpu_info"                  => [
                                             {
                                               address_width                => 64,
@@ -173,7 +210,6 @@ our $results = [
                                                                                 "xtopology",
                                                                                 "nonstop_tsc",
                                                                                 "aperfmperf",
-                                                                                "eagerfpu",
                                                                                 "pni",
                                                                                 "pclmulqdq",
                                                                                 "dtes64",
@@ -184,6 +220,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "sdbg",
                                                                                 "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
@@ -203,12 +240,8 @@ our $results = [
                                                                                 "lahf_lm",
                                                                                 "abm",
                                                                                 "3dnowprefetch",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
+                                                                                "intel_pt",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
@@ -228,6 +261,11 @@ our $results = [
                                                                                 "adx",
                                                                                 "smap",
                                                                                 "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -236,7 +274,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2768.007,
+                                              speed                        => 2794.445,
                                               stepping                     => 4,
                                             },
                                             {
@@ -288,7 +326,6 @@ our $results = [
                                                                                 "xtopology",
                                                                                 "nonstop_tsc",
                                                                                 "aperfmperf",
-                                                                                "eagerfpu",
                                                                                 "pni",
                                                                                 "pclmulqdq",
                                                                                 "dtes64",
@@ -299,6 +336,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "sdbg",
                                                                                 "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
@@ -318,12 +356,8 @@ our $results = [
                                                                                 "lahf_lm",
                                                                                 "abm",
                                                                                 "3dnowprefetch",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
+                                                                                "intel_pt",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
@@ -343,6 +377,11 @@ our $results = [
                                                                                 "adx",
                                                                                 "smap",
                                                                                 "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -351,7 +390,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2600.007,
+                                              speed                        => 2857.421,
                                               stepping                     => 4,
                                             },
                                             {
@@ -403,7 +442,6 @@ our $results = [
                                                                                 "xtopology",
                                                                                 "nonstop_tsc",
                                                                                 "aperfmperf",
-                                                                                "eagerfpu",
                                                                                 "pni",
                                                                                 "pclmulqdq",
                                                                                 "dtes64",
@@ -414,6 +452,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "sdbg",
                                                                                 "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
@@ -433,12 +472,8 @@ our $results = [
                                                                                 "lahf_lm",
                                                                                 "abm",
                                                                                 "3dnowprefetch",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
+                                                                                "intel_pt",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
@@ -458,6 +493,11 @@ our $results = [
                                                                                 "adx",
                                                                                 "smap",
                                                                                 "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -466,7 +506,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2870.054,
+                                              speed                        => 2890.319,
                                               stepping                     => 4,
                                             },
                                             {
@@ -518,7 +558,6 @@ our $results = [
                                                                                 "xtopology",
                                                                                 "nonstop_tsc",
                                                                                 "aperfmperf",
-                                                                                "eagerfpu",
                                                                                 "pni",
                                                                                 "pclmulqdq",
                                                                                 "dtes64",
@@ -529,6 +568,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "sdbg",
                                                                                 "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
@@ -548,12 +588,8 @@ our $results = [
                                                                                 "lahf_lm",
                                                                                 "abm",
                                                                                 "3dnowprefetch",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
+                                                                                "intel_pt",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
@@ -573,6 +609,11 @@ our $results = [
                                                                                 "adx",
                                                                                 "smap",
                                                                                 "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -581,57 +622,58 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2599.953,
+                                              speed                        => 2728.906,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.325592994689941,
+      "func.elapsed_time"              => 0.369853973388672,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                              => 1.036,
+                                            "__PACKAGE__"                              => 1.041,
                                             "Bencher::Scenario::CmdLineParsingModules" => undef,
-                                            "Benchmark::Dumb"                          => "0.10",
-                                            "Complete::Bash"                           => 0.31,
+                                            "Benchmark::Dumb"                          => 0.111,
+                                            "Complete::Bash"                           => "0.320",
                                             "Devel::Platform::Info"                    => 0.16,
                                             "Parse::CommandLine"                       => 0.02,
-                                            "perl"                                     => "v5.24.0",
+                                            "Parse::CommandLine::Regexp"               => 0.001,
+                                            "perl"                                     => "v5.26.1",
                                             "Sys::Info"                                => 0.78,
                                             "Text::ParseWords"                         => "3.30",
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0, 1, 2], "dataset", [0 .. 3]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 3], "dataset", [0 .. 3]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "rosa",
+                                            codename => "sylvia",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.19.0-32-generic",
+                                            kernel   => "linux-4.10.0-38-generic",
                                             kname    => "Linux",
-                                            kvers    => "3.19.0-32-generic",
+                                            kvers    => "4.10.0-38-generic",
                                             osflag   => "linux",
                                             oslabel  => "LinuxMint",
                                             osname   => "GNU/Linux",
-                                            osvers   => 17.3,
+                                            osvers   => 18.3,
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
-                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Linux Mint 18.3 Sylvia \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.3 Sylvia\nRelease:\t18.3\nCodename:\tsylvia",
+                                                          "uname -a"        => "Linux backpacker 4.10.0-38-generic #42~16.04.1-Ubuntu SMP Tue Oct 10 16:32:20 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.19.0-32-generic",
+                                                          "uname -r"        => "4.10.0-38-generic",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::CmdLineParsingModules",
-      "func.scenario_module_md5sum"    => "7762abd55864f9518393c4a6d6822a7e",
-      "func.scenario_module_mtime"     => 1495581503,
-      "func.scenario_module_sha1sum"   => "f1a2e5a0f1131c55ab1b90463ca58c6e30c2bda4",
-      "func.scenario_module_sha256sum" => "d181752859155e4a7f13554551fd659bd21c291d0f5d9fad68e5e2dd987d6954",
-      "func.time_end"                  => 1495581627.22335,
+      "func.scenario_module_md5sum"    => "975cf7fa066a82d4f9367945a233b067",
+      "func.scenario_module_mtime"     => 1549763218,
+      "func.scenario_module_sha1sum"   => "bef81382eb14d64f0b78a6e07e25571c66737e97",
+      "func.scenario_module_sha256sum" => "ce1996ab0aaa9a429c0aa0da9d78864d68ead7ef241706d2af0fc6c70c96d49b",
+      "func.time_end"                  => 1549763959.85554,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1495581626.89775,
+      "func.time_start"                => 1549763959.48568,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
